<div align="center">
  <p>
  <img src="https://image.freepik.com/free-vector/pathogen-microorganisms-set_74855-5909.jpg" alt="https://www.freepik.com/pch-vector" width="270" />
  </p>
  <p>
    <a href="">
      <img alt="First release" src="https://img.shields.io/badge/release-v1.0-brightgreen.svg" />
    </a>
  </p>
  
  <p>
    <a href="https://microbiome-toolbox.herokuapp.com">
      Dashboard
    </a>
  </p>
</div>


# Microbiome Toolbox

Microbiome toolbox is a collection of tools and methods for microbiome data and it includes data analysis and exploration, data preparation, microbiome trajectory modeling, outlier discovery and intervention.

```
# create environment
conda env create -f environment.yml

# activate environment
conda activate microbiome

# install microbiome toolbox
pip install microbiome-toolbox --user
```
